@@ -1,7 +1,7 @@
 test_that("Whether multi-core parallel computing is the same as single-core computing in gos_bestkappa", {
   data("zn")
   zn$Zn <- log(zn$Zn)
-  k <- SecDim::rmvoutlier(zn$Zn, coef = 2.5)
+  k <- removeoutlier(zn$Zn, coef = 2.5)
   dt <- zn[-k,]
   b1 <- gos_bestkappa(Zn ~ Slope + Water + NDVI  + SOC + pH + Road + Mine,
                       data = dt,
